View source: R/hvsr_win_calc.R
| hvsr_win_calc | R Documentation |
This function calculates HVSR and polar HVSR for the given window
hvsr_win_calc(
i_win,
h1_wins,
h2_wins,
v_wins,
dt,
horizontal_comb = "geometric_mean",
freq_hv_mean,
polar_curves_flag = TRUE,
freq_polar,
deg_increment = 10
)
i_win |
The index of running window |
h1_wins |
A list of 1st horizontal component time series. Each element is for one window |
h2_wins |
A list of 2nd horizontal component time series. Each element is for one window |
v_wins |
A list of vertical horizontal component time series. Each element is for one window |
dt |
The time step |
horizontal_comb |
The parameter specifies the combination of two horizontal components. ps_RotD50: rotated combination at the angle where PGA is median; geometric_mean: geometric mean (sqrt(h1(f) * h2(f))); squared_average: squared average (sqrt((h1(f)^2 + h2(f)^2)/2)) |
freq_hv_mean |
The target frequencys of HVSR |
polar_curves_flag |
The flag indicates if polar curves are calculated |
freq_polar |
The target frequencys of polar HVSR |
deg_increment |
The degree increment for HVSR polar curves |
The HVSR for the given window
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.