peak_fit_manual: A function for HVSR peak detection and fitting manually

View source: R/peak_fit.R

peak_fit_manualR Documentation

A function for HVSR peak detection and fitting manually

Description

This function takes the user defined frequency range (lower bound and upper bound) and use the Gaussian pulse function to fit the peak. The fitted parameters are returned.

Usage

peak_fit_manual(x_freq, hvsr_mean, fit_range_lb, fit_range_ub)

Arguments

x_freq

The array of frequnecy (in Hz)

hvsr_mean

The array of HVSR mean curve

fit_range_lb

The lower frequency bound for a HVSR peak (in Hz)

fit_range_ub

The upper frequency bound for a HVSR peak (in Hz)


wltcwpf/hvsrProc documentation built on March 25, 2024, 7 p.m.