| bw_pass | R Documentation |
This function applies low-pass Butterworth filter to process time series (for both causal and acausal)
bw_pass(ts, dt, fc, nPole = 4, is_causal = FALSE, order_zero_padding = 0)
ts |
An array of time series |
dt |
The time step |
fc |
The corner frequency for low-pass/high-pass |
nPole |
The pole parameter for the order, where the order is 2 * nPole. Positive for low-pass; Negative for high-pass Generally, nPole = 4 for low-pass and nPole = -5 for high-pass |
is_causal |
A binary to indicator if causal is applied. Apply causal if is_causal = TRUE and apply acausal if is_causal = FALSE |
order_zero_padding |
The order needs to be added for zeroes padding at the end of recordings to increase the number of data points to a power of 2 (Kishida T., Darragh R.B., Chiou B.S.J., Bozorgnia Y., Mazzoni S., Contreras V., Boroschek R., Rojas F., Stewart J.P., 2020. Chapter 3: Ground Motions and Intensity Measures, in Data Resources for NGA-Subduction Project, PEER Report 2020/02, J.P. Stewart (editor), Pacific Earthquake Engineering Research Center, UC Berkeley (headquarters).). Default is 0 (no zero-padding). |
The filtered time series
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.