| peak_fit_manual | R Documentation |
This function takes the user defined frequency range (lower bound and upper bound) and use the Gaussian pulse function to fit the peak. The fitted parameters are returned.
peak_fit_manual(x_freq, hvsr_mean, fit_range_lb, fit_range_ub)
x_freq |
The array of frequnecy (in Hz) |
hvsr_mean |
The array of HVSR mean curve |
fit_range_lb |
The lower frequency bound for a HVSR peak (in Hz) |
fit_range_ub |
The upper frequency bound for a HVSR peak (in Hz) |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.